Class: Google::Cloud::PubSub::FlowControlLimitError
- Inherits:
-
Error
- Object
- Error
- Google::Cloud::PubSub::FlowControlLimitError
- Defined in:
- lib/google/cloud/pubsub/errors.rb
Overview
Raised when the desired action is error and the message would exceed
flow control limits, or when the desired action is block and the
message would block forever against the flow control limits.