Class: Google::Cloud::PubSub::TopicAdmin::Client

Inherits:
V1::TopicAdmin::Client
  • Object
show all
Defined in:
lib/google/cloud/pubsub/admin_clients.rb

Overview

The TopicAdmin client is used to manage topics.

This client is a subclass of the auto-generated TopicAdmin client, and provides the same methods. However, it raises errors on data plane operations to prevent misuse.

Instance Method Summary collapse

Instance Method Details

#publish(*args, **kwargs) ⇒ Object

The publish method is a data plane operation.

Raises:

  • (NotImplementedError)

    This method is not implemented on the admin client. Use Publisher instead.



39
40
41
42
43
# File 'lib/google/cloud/pubsub/admin_clients.rb', line 39

def publish *args, **kwargs
  raise NotImplementedError,
        "The `publish` method is a data plane operation. " \
        "Use Google::Cloud::PubSub::Publisher instead."
end